"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.massageIndexOptions = exports.command = void 0;
const the_lodash_1 = __importDefault(require("the-lodash"));
const logger_1 = require("../../logger");
const path_1 = __importDefault(require("path"));
const fs_1 = require("fs");
const command_1 = require("../guard/command");
const kubevious_1 = require("../../types/kubevious");
const yaml_1 = __importDefault(require("yaml"));
const path_2 = require("../../utils/path");
function command(dir, options) {
    return __awaiter(this, void 0, void 0, function* () {
        logger_1.logger.info("[Dir] ", dir);
        const guardResult = yield (0, command_1.command)([dir], {
            ignoreUnknown: true,
            ignoreNonK8s: true,
            stream: false,
            skipApplyCrds: false,
            liveK8s: false,
            includeRemoteTargets: false,
            skipLocalRules: false,
            skipRemoteRules: true,
            areNamespacesSpecified: false,
            namespaces: [],
            skipClusterScope: false,
            skipCommunityRules: true,
            skipRuleLibraries: true,
        });
        const manifestPackage = guardResult.manifestPackage;
        const libraryFilePath = path_1.default.join(dir, 'index.yaml');
        const libraryObject = {
            apiVersion: `${kubevious_1.KUBEVIOUS_API_NAME}/${kubevious_1.KUBEVIOUS_API_VERSION}`,
            kind: kubevious_1.KubeviousKinds.Library,
            metadata: {
                name: 'community'
            },
            spec: {
                rules: []
            }
        };
        const rules = guardResult.localK8sRegistry.query({
            isApiVersion: false,
            apiOrNone: kubevious_1.KUBEVIOUS_API_NAME,
            kind: kubevious_1.KubeviousKinds.ClusterRule,
            isAllNamespaces: true,
        });
        for (const rule of rules) {
            logger_1.logger.info("LIBRARY RULE: %s", rule.idKey);
            const rulePath = (0, path_2.makeRelativePath)(rule.source.source.path, dir);
            libraryObject.spec.rules.push({
                name: rule.id.name,
                path: rulePath
            });
        }
        libraryObject.spec.rules = the_lodash_1.default.orderBy(libraryObject.spec.rules, [x => x.name, x => x.path]);
        if (guardResult.success) {
            yield fs_1.promises.writeFile(libraryFilePath, yaml_1.default.stringify(libraryObject, {
                toStringDefaults: {
                    indent: 2,
                    indentSeq: false
                }
            }));
        }
        const success = guardResult.success;
        return {
            success,
            manifestPackage,
            guardCommandData: guardResult,
            libraryDir: dir,
            libraryPath: libraryFilePath,
            libraryObject,
            rules,
        };
    });
}
exports.command = command;
function massageIndexOptions(options) {
    return {};
}
exports.massageIndexOptions = massageIndexOptions;
//# sourceMappingURL=command.js.map