"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sTargetQuery = void 0;
const base_1 = require("../base");
class K8sTargetQuery {
    constructor() {
        this._kind = base_1.TargetQueryKind.K8s;
        this._data = {
            isApiVersion: true,
            nameFilters: [],
            labelFilters: [],
        };
    }
    get kind() {
        return this._kind;
    }
    ApiVersion(apiVersion) {
        this._data.isApiVersion = true;
        this._data.apiVersion = apiVersion;
        return this;
    }
    Api(apiOrNone) {
        this._data.isApiVersion = false;
        this._data.apiOrNone = apiOrNone;
        return this;
    }
    Version(version) {
        this._data.version = version;
        return this;
    }
    Kind(kind) {
        this._data.kind = kind;
        return this;
    }
    namespace(value) {
        this._data.namespace = value;
        return this;
    }
    allNamespaces() {
        this._data.isAllNamespaces = true;
        return this;
    }
    name(value) {
        this._data.nameFilters.push(value);
        return this;
    }
    label(key, value) {
        const filter = {};
        filter[key] = value;
        return this.labels(filter);
    }
    labels(value) {
        this._data.labelFilters.push(value);
        return this;
    }
}
exports.K8sTargetQuery = K8sTargetQuery;
//# sourceMappingURL=k8s-target-query.js.map