"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.K8sQueryExecutor = void 0;
const script_item_1 = require("../../script-item");
class K8sQueryExecutor {
    constructor(executionContext) {
        this._executionContext = executionContext;
        this._logger = executionContext.logger.sublogger("K8sQueryExecutor");
    }
    execute(query, limiter) {
        var _a;
        this._logger.info("[execute] RUNNING QUERY....");
        const queryData = query._data;
        if (!queryData.kind) {
            console.log("No Kind");
            return {
                success: false,
                messages: ['Kind not set'],
            };
        }
        const apiVersion = queryData.isApiVersion ? queryData.apiVersion :
            (queryData.apiOrNone ? `${queryData.apiOrNone}/${queryData.version}` : queryData.version);
        if (!apiVersion) {
            console.log("No ApiVersion");
            return {
                success: false,
                messages: ['No ApiVersion not set'],
            };
        }
        const k8sQueryFilter = {
            isApiVersion: true,
            apiVersion: apiVersion,
            kind: queryData.kind,
            namespace: queryData.namespace,
            isAllNamespaces: queryData.isAllNamespaces,
            nameFilters: queryData.nameFilters,
            labelFilters: queryData.labelFilters,
        };
        // TODO: Handle Clustered Case Properly.
        const isAllNamespaces = (_a = k8sQueryFilter.isAllNamespaces) !== null && _a !== void 0 ? _a : false;
        if (!isAllNamespaces) {
            if (limiter.namespace) {
                k8sQueryFilter.namespace = limiter.namespace;
            }
        }
        const manifests = this._executionContext.registryQueryExecutor.query(k8sQueryFilter);
        const result = {
            success: true,
            items: manifests.map(x => new script_item_1.ScriptItem(x))
        };
        this._logger.info("[execute]     RESULT COUNT: %s", result.items.length);
        return result;
    }
}
exports.K8sQueryExecutor = K8sQueryExecutor;
//# sourceMappingURL=k8s-query-executor.js.map